
;**************************************************************************
;*                             KOCKA                                      *
;**************************************************************************
;*          2x7 LEDs connected to PORTB & PORTA                           *
;*          4 buttons are used                                            *
;**************************************************************************
;*          v 1.17 - 09.09.2009                                           *
;**************************************************************************
;*          Hardw.: PIC16F627A used                                       *
;*          OSC.......: Internal osc. used     POWER.....:  3x1,2V accu   *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
PORTA                        EQU     H'0005'
PORTB                        EQU     H'0006'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISA                        EQU     H'0085'
TRISB                        EQU     H'0086'
CMCON                        EQU     H'001F'

PCON                         EQU     H'008E'
PIR1                         EQU     H'000C'	;bank0
PIE1                         EQU     H'008C'	;bank1
T2CON                        EQU     H'0012'	;bank0

TMR2                         EQU     H'0011'	;bank0
PR2			     EQU     H'0092'	;bank1

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'

	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_ON & _INTRC_OSC_NOCLKOUT

;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	
TIMER3		equ	H'22'
TIMER4		equ	H'23'
k1r		equ	H'24'
k2g		equ	H'25'
TIMER11		equ	H'26'
TIMER12		equ	H'27'
TIMER13		equ	H'28'
sleep_act	equ	H'29'
k1r_save	equ	H'2A'
k2g_save	equ	H'2B'
ftf		equ	H'2C'

w_save		EQU	H'36'
s_save		EQU	H'37'
save_portb	EQU	H'38'

;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

		ORG	004
		goto	int_serv

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'01010111'	;Set PIC options (See datasheet).

;RBPU bit (bit 7 of option reg); if RBPU eq 0 --> pull-ups are active....

		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts

		MOVLW	B'11110000'	;RB4 - RB7: input
		MOVWF	TRISB
		MOVLW	B'00110000'	;RAx- input
		MOVWF	TRISA

		bsf	PCON,D'003'	;set 4MHz oscilator frequency


		movlw	D'200'		;stop value for TIMER2
		movwf	PR2

		BCF	STATUS,RP0	;Switch Back to reg. Bank 0

		movlw	D'255'
		movwf	ftf		;first time flag

;----------------------------------------------------------------------------------
wu_tmp
		clrf	PORTA
		clrf	PORTB

		call	demo1x

		movlw	B'00000001'
		movwf	k1r
		movwf	k2g

		call	gx
		call	rx

		movlw	D'005'
		movwf	TIMER3
		movlw	D'001'
		movwf	TIMER4

		movlw	D'255'
		movwf	TIMER11
		movwf	TIMER12
		movlw	D'10'
		movwf	TIMER13

		clrf	sleep_act

;set-up interrupts -----------------------------------------------------------------
		clrf	INTCON		;disable all interrupts

		BSF	STATUS,RP0
;bit 0 enables RB4-RB7 value change interrupt
		movlw	B'00000010'	;enable TIMER2 interrupt
		movwf	PIE1
		BCF	STATUS,RP0

		clrf	T2CON
		clrf	TMR2

		movlw	B'11000000'	;enable interrupts & peripheral interrupts
		movwf	INTCON		;set-up interrupts

;set-up TIMER2
;prescaler: 1:4
;postscaler: 1:15
;timer on
		movlw	B'01110101'
		movwf	T2CON

		goto	main
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


aa0		movlw	D'255'
		movwf	TIMER11
		movwf	TIMER12
		movlw	D'255'
		movwf	TIMER13
		return


main		call	aa0

		btfss	ftf,D'000'
		goto	aa22
		clrf	ftf
		goto	aa1

aa22		call	display01


aa1		DECFSZ  TIMER11,F
		goto	aa11_ok
		movlw	D'255'
		movwf	TIMER11
		DECFSZ  TIMER12,F
		goto	aa11_ok
		movlw	D'255'
		movwf	TIMER11
		movwf	TIMER12
		decfsz	TIMER13,F
		goto	aa11_ok
		movlw	D'255'
		movwf	TIMER11
		movlw	D'255'
		movwf	TIMER12
		movlw	D'100'
		movwf	TIMER13

		clrf	PORTA
		clrf	PORTB

;we are about to go to sleep; just to mark a flag... and sleep

		clrf	INTCON		;disable all interrupts

		nop
		nop
		nop
		nop

		bsf	sleep_act,D'000'

		movlw	B'10001000'	;enable interrupts & RB interrupts
		movwf	INTCON		;set-up interrupts

sp1		sleep
		goto	sp1

		clrf	PORTA
		clrf	PORTB


aa11_ok		btfss	PORTB,D'007'
		goto	key3
		btfss	PORTB,D'006'
		goto	key2
		btfss	PORTB,D'005'
		goto	key1
		btfss	PORTB,D'004'
		goto	key4
		goto	aa1

;obe kocky
key3		rlf	k1r,1
		btfsc	k1r,D'007'
		call	k1r_set1

		movf	k1r,0
		movwf	k1r_save

		movf	k2g,0
		movwf	k2g_save

		call	display01
		call	dr2
		btfsc	PORTB,D'007'
		goto	key3_fin
		goto	key3

;zelena kocka
key2		movf	k2g,0
		movwf	k2g_save
		call	disp_g
		btfsc	PORTB,D'006'
		goto	key3_fin
		btfss	PORTB,D'005'
		goto	demo
		goto	key2

key1		rlf	k1r,1
		btfsc	k1r,D'007'
		call	k1r_set1
		call	dr2

		movf	k1r,0
		movwf	k1r_save

		call	disp_r
		btfsc	PORTB,D'005'
		goto	key3_fin
		btfss	PORTB,D'006'
		goto	demo
		goto	key1

key4		call	g7
		call	r7
key4b		btfsc	PORTB,D'004'
		goto	key4_fin
		goto	key4b

key4_fin	call	display01
		goto	key3_fin

key3_fin
;set count down counter...

		call	aa0
		goto	aa1	

;----------------------------------------------------------
k1r_set1	movlw	B'00000001'
		movwf	k1r
		return
;----------------------------------------------------------
k2g_set1	movlw	B'00000001'
		movwf	k2g
		return

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
display01	call	disp_g
		call	disp_r
		return
;--------------------------------------------------------------------------

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;x             interrupt service routine                              x
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;
;TIMER2 input is int.osc./4

int_serv
;save STATUS & W
		bcf	INTCON,D'007'

		movwf	w_save
		swapf	STATUS, w
		movwf	s_save
;main interrupt routine

		btfss	sleep_act,D'000'
		goto	tmr2_ir
		bcf	INTCON,D'000'

		movlw	B'00001111'
		movwf	PORTA
		movwf	PORTB
		call	dr3
		clrf	PORTA
		clrf	PORTB
		call	dr3
		movlw	B'00001111'
		movwf	PORTA
		movwf	PORTB
		call	dr3
		clrf	PORTA
		clrf	PORTB
		call	dr3
		movlw	B'00001111'
		movwf	PORTA
		movwf	PORTB
		call	dr3
		clrf	PORTA
		clrf	PORTB
		call	dr3

		goto	wu_tmp

;--------------------------------------------------------------------
tmr2_ir		DECFSZ  TIMER3,F
		goto	nyncen
		movlw	D'001'
		movwf	TIMER3
		DECFSZ  TIMER4,F
		goto	nyncen

		movlw	D'001'
irc11		movwf	TIMER4

		clrf	TMR2

;increment the numer for green... ------------------
		rlf	k2g,1
		btfsc	k2g,D'007'
		call	k2g_set1

		bcf	PIR1,D'001'		;clear the TMR2IF flag
;---------------------------------------------------
;restore STATUS & W

nyncen
		swapf	s_save,w
		movwf	STATUS
		swapf	w_save, f
		swapf	w_save, w

		bsf	INTCON,D'007'
		retfie

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;x     END     interrupt service routine       END                    x
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;-------------------------------------------
disp_g		btfsc	k2g_save,D'001'
		goto	g1
		btfsc	k2g_save,D'002'
		goto	g2
		btfsc	k2g_save,D'003'
		goto	g3
		btfsc	k2g_save,D'004'
		goto	g4
		btfsc	k2g_save,D'005'
		goto	g5
		btfsc	k2g_save,D'006'
		goto	g6
		return
;-------------------------------------------
disp_r		btfsc	k1r_save,D'001'
		goto	r1
		btfsc	k1r_save,D'002'
		goto	r2
		btfsc	k1r_save,D'003'
		goto	r3
		btfsc	k1r_save,D'004'
		goto	r4
		btfsc	k1r_save,D'005'
		goto	r5
		btfsc	k1r_save,D'006'
		goto	r6
		return

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
gx		clrf	PORTB
		bsf	PORTB,D'000'
		return

g0		clrf	PORTB
		return

g1		clrf	PORTB
		bsf	PORTB,D'003'
		return

g2		clrf	PORTB
		bsf	PORTB,D'001'
		return

g3		clrf	PORTB
		bsf	PORTB,D'003'
		bsf	PORTB,D'001'
		return

g4		clrf	PORTB
		bsf	PORTB,D'001'
		bsf	PORTB,D'002'
		return

g5		clrf	PORTB
		bsf	PORTB,D'001'
		bsf	PORTB,D'002'
		bsf	PORTB,D'003'
		return

g6		clrf	PORTB
		bsf	PORTB,D'000'
		bsf	PORTB,D'001'
		bsf	PORTB,D'002'
		return

g7		clrf	PORTB
		bsf	PORTB,D'000'
		bsf	PORTB,D'001'
		bsf	PORTB,D'002'
		bsf	PORTB,D'003'
		return
;-------------------------------------------------------
rx		clrf	PORTA
		bsf	PORTA,D'000'
		return

r0		clrf	PORTA
		return

r1		clrf	PORTA
		bsf	PORTA,D'003'
		return

r2		clrf	PORTA
		bsf	PORTA,D'001'
		return

r3		clrf	PORTA
		bsf	PORTA,D'003'
		bsf	PORTA,D'001'
		return

r4		clrf	PORTA
		bsf	PORTA,D'001'
		bsf	PORTA,D'002'
		return

r5		clrf	PORTA
		bsf	PORTA,D'001'
		bsf	PORTA,D'002'
		bsf	PORTA,D'003'
		return

r6		clrf	PORTA
		bsf	PORTA,D'000'
		bsf	PORTA,D'001'
		bsf	PORTA,D'002'
		return

r7		clrf	PORTA
		bsf	PORTA,D'000'
		bsf	PORTA,D'001'
		bsf	PORTA,D'002'
		bsf	PORTA,D'003'
		return


;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

;		*********************************************
;		*               delay routine               *
;		*********************************************

DELAY_ROUTINE	MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'255'
		MOVWF   TIMER1

		btfss	PORTB,D'007'
		goto	aa1

DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		return

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

DELAY_ROUTINE5	MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOPx1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOPx2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOPx2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOPx1
		return

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx


dr2		MOVLW   D'20'
		MOVWF   TIMER2
DEL_LOOP21	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP22	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP22
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP21
		return

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
dr3		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP31	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP32	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP32
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP31
		return

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

demo		call	demo1
		call	demo2
		goto	demo

demo1x		call	g1
		call	r1
		CALL	DELAY_ROUTINE5
		call	g2
		call	r2
		CALL	DELAY_ROUTINE5
		call	g3
		call	r3
		CALL	DELAY_ROUTINE5
		call	g4
		call	r4
		CALL	DELAY_ROUTINE5
		call	g5
		call	r5
		CALL	DELAY_ROUTINE5
		call	g6
		call	r6
		CALL	DELAY_ROUTINE5
		return


demo1		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		call	g2
		call	r2
		CALL	DELAY_ROUTINE
		call	g3
		call	r3
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		call	g5
		call	r5
		CALL	DELAY_ROUTINE
		call	g6
		call	r6
		CALL	DELAY_ROUTINE
		return

demo2		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		call	g2
		call	r2
		CALL	DELAY_ROUTINE
		call	g3
		call	r3
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		call	g5
		call	r5
		CALL	DELAY_ROUTINE
		call	g6
		call	r6
		CALL	DELAY_ROUTINE

		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		call	g2
		call	r2
		CALL	DELAY_ROUTINE
		call	g3
		call	r3
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		call	g5
		call	r5
		CALL	DELAY_ROUTINE
		call	g6
		call	r6
		CALL	DELAY_ROUTINE

		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		call	g2
		call	r2
		CALL	DELAY_ROUTINE
		call	g3
		call	r3
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		call	g5
		call	r5
		CALL	DELAY_ROUTINE
		call	g6
		call	r6
		CALL	DELAY_ROUTINE

		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		call	g2
		call	r2
		CALL	DELAY_ROUTINE
		call	g3
		call	r3
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		call	g5
		call	r5
		CALL	DELAY_ROUTINE
		call	g6
		call	r6
		CALL	DELAY_ROUTINE
;***************************************************
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
;------------------------------------------------------
		call	g1
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r5
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g3
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g5
		call	r2
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE


		call	g1
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r5
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g3
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g5
		call	r2
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE


		call	g1
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r5
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g3
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g5
		call	r2
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE



		call	g1
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r5
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g3
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g5
		call	r2
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE

;*****************************************************
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
;---------------------------------------------------
		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE

		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r3
		CALL	DELAY_ROUTINE				
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE

		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE

		call	g1
		call	r1
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g4
		call	r4
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g2
		call	r6
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		call	g6
		call	r3
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
;**********************************************************
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE
		call	r0
		call	g0
		CALL	DELAY_ROUTINE
		call	r6
		call	g6
		CALL	DELAY_ROUTINE


		return

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

		END